#!/etc/opt/openit/perl

###############################################################################
#
# Updates CalcSum:product to fix the bug in calculating max-available of features on different mappings
#
#

BEGIN {
    push @INC, "/opt/openit/contrib/lib";
}

use strict;

use OpeniT::Contrib::Config;

my $config = new OpeniT::Contrib::Config;               # Reads default config file(s)
$config->read("/etc/opt/openit/openit_contrib.cfg");    # Additional config

#
# Get Open iT config directory (and verify value)
#
my $cfg_dir = $config->{CONFIG_DIR};
if (! -d $cfg_dir) {
    die "Unable to locate Open iT config ($cfg_dir) directory";
}

# Get list of filters to update
# get filters with Calcsum:product
my @filter_files = &get_filters_to_update("$cfg_dir/filtrator");

foreach my $filter (@filter_files) {
    &update_filter( $filter );
}

exit 0;


###############################################################################
#
# Scan filter directory and get list of files to update
#
sub get_filters_to_update {
    my ($filter_dir) = @_;
    
    my @filters = glob("$filter_dir/*.conf");
    my @included_filters;
    
    foreach my $filter (@filters) {
        open(FILE, $filter) || die "Unable to read filter file '$filter'";
        my @lines = <FILE>;
        close(FILE);

        if( grep {/CalcSum:product/} @lines ) {	
            push( @included_filters, $filter );
        }
    }
    return @included_filters;
}


###############################################################################
#
# Update filter files
#
sub update_filter {
    my ($filter) = @_;

    open(FILE, $filter) || die "Unable to read filter file '$filter'";
    my @lines = <FILE>;
    close(FILE);

    my $ind = 0;
    $ind++ while( $lines[$ind] !~ /filter-defs/ );
    $ind++ while( $lines[$ind] !~ /CalcSum:product/ );
    $ind++ while( $lines[$ind] !~ /remove\(String\)/ );

    if( grep {/remove\(String\)=.*\Wproduct\W.*/} @lines[$ind] ) {
	$lines[$ind] =~ s/product,//g;
	$lines[$ind] =~ s/,product//g;
	$lines[$ind] =~ s/product//g;
    }
    else {
        return;
    }

    print "Updating '$filter'\n";

    my $new = "$filter.new";
    my $old = "$filter.old";

    # Create new tmp file
    open(OUT, ">$new") || die "Unable to create tmp file '$new'";
    print OUT @lines;
    close(OUT);

    # Mv old file to .old
    if ( ! rename $filter, $old ) {
        die "Unable to rename '$filter'";
    }

    # Rename new
    if ( ! rename $new, $filter ) {
        die "Unable to rename '$new'";
    }

}



